"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isOverrideStyleArray = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const styles = react_native_1.StyleSheet.create({
    between: {
        justifyContent: 'space-between',
    },
    around: {
        justifyContent: 'space-around',
    },
    evenly: {
        justifyContent: 'space-evenly',
    },
    middle: {
        justifyContent: 'center',
    },
    top: {
        justifyContent: 'flex-start',
    },
    bottom: {
        justifyContent: 'flex-end',
    },
    center: {
        alignItems: 'center',
    },
    start: {
        alignItems: 'flex-start',
    },
    end: {
        alignItems: 'flex-end',
    },
    column: {
        flexDirection: 'column',
    },
    row: {
        flexDirection: 'row',
    },
    rowReverse: {
        flexDirection: 'row-reverse',
    },
    columnReverse: {
        flexDirection: 'column-reverse',
    },
    wrapReverse: {
        flexWrap: 'wrap-reverse',
    },
    wrap: {
        flexWrap: 'wrap',
    },
    common: {
        backgroundColor: 'white',
    },
});
const defaultProps = {
    column: true,
};
const isOverrideStyleArray = (str) => str !== undefined;
exports.isOverrideStyleArray = isOverrideStyleArray;
const Flex = ({ children, between, around, evenly, center, start, end, middle, top, bottom, row, rowReverse, columnReverse, column, flex, overrideStyle, wrapReverse, wrap, onLayout, testID, nativeID, pointerEvents, }) => {
    let styleArray = [styles.column];
    const rowStyle = [];
    if (flex) {
        styleArray.push({ flex });
        rowStyle.push({ flex });
    }
    if (center) {
        styleArray.push(styles.center);
    }
    else if (start) {
        styleArray.push(styles.start);
    }
    else if (end) {
        styleArray.push(styles.end);
    }
    if (between) {
        styleArray.push(styles.between);
    }
    else if (around) {
        styleArray.push(styles.around);
    }
    else if (evenly) {
        styleArray.push(styles.evenly);
    }
    else if (middle) {
        styleArray.push(styles.middle);
    }
    else if (top) {
        styleArray.push(styles.top);
    }
    else if (bottom) {
        styleArray.push(styles.bottom);
    }
    // Flex directions
    if (row) {
        styleArray.push(styles.row);
    }
    else if (rowReverse) {
        styleArray.push(styles.rowReverse);
    }
    else if (columnReverse) {
        styleArray.push(styles.columnReverse);
    }
    else {
        styleArray.push(styles.column);
    }
    // Flex directions
    if (wrapReverse) {
        styleArray.push(styles.wrapReverse);
    }
    else if (wrap) {
        styleArray.push(styles.wrap);
    }
    if (overrideStyle) {
        if ((0, exports.isOverrideStyleArray)(overrideStyle) && Array.isArray(overrideStyle)) {
            styleArray = [...styleArray, ...overrideStyle];
        }
        else {
            styleArray.push(overrideStyle);
        }
    }
    let flexComponent = null;
    if (!children) {
        return flexComponent;
    }
    if (row || rowReverse) {
        flexComponent = (react_1.default.createElement(react_native_1.View, { pointerEvents: pointerEvents, style: rowStyle, onLayout: onLayout, testID: testID },
            react_1.default.createElement(react_native_1.View, { nativeID: nativeID, style: styleArray }, children)));
    }
    else if (columnReverse || column) {
        flexComponent = (react_1.default.createElement(react_native_1.View, { pointerEvents: pointerEvents, nativeID: nativeID, style: styleArray, onLayout: onLayout, testID: testID }, children));
    }
    return flexComponent;
};
Flex.defaultProps = defaultProps;
exports.default = Flex;
