"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const clipboard_1 = __importDefault(require("@react-native-community/clipboard"));
const helpers_1 = require("../UikitUtils/helpers");
const inputOtpTextStyle_1 = require("./inputOtpTextStyle");
const colors_1 = require("../UikitUtils/colors");
const themeHelper_1 = require("../UikitUtils/themeHelper");
const ThemeContext_1 = __importDefault(require("../ThemeContext/ThemeContext"));
class InputOtpText extends react_1.Component {
    static defaultProps = {
        pinCount: 6,
        autoFocusOnLoad: true,
        secureTextEntry: false,
        editable: true,
        keyboardAppearance: 'default',
        keyboardType: 'number-pad',
        clearInputs: false,
        placeholderCharacter: '',
        selectionColor: '#000',
        type: 'curved',
    };
    fields = [];
    keyboardDidHideListener;
    timer;
    hasCheckedClipBoard;
    clipBoardCode;
    constructor(props) {
        super(props);
        const { code } = props;
        this.state = {
            digits: (0, helpers_1.codeToArray)(code),
            selectedIndex: props.autoFocusOnLoad ? 0 : -1,
        };
    }
    UNSAFE_componentWillReceiveProps(nextProps) {
        const { code } = this.props;
        if (nextProps.code !== code) {
            this.setState({ digits: (0, helpers_1.codeToArray)(nextProps.code) });
        }
    }
    componentDidMount() {
        this.copyCodeFromClipBoardOnAndroid();
        this.bringUpKeyBoardIfNeeded();
        this.keyboardDidHideListener = react_native_1.Keyboard.addListener('keyboardDidHide', this.handleKeyboardDidHide);
    }
    componentWillUnmount() {
        if (this.timer) {
            clearInterval(this.timer);
        }
        this.keyboardDidHideListener?.remove();
    }
    copyCodeFromClipBoardOnAndroid = () => {
        if (react_native_1.Platform.OS === 'android') {
            this.checkPinCodeFromClipBoard();
            this.timer = setInterval(this.checkPinCodeFromClipBoard, 400);
        }
    };
    bringUpKeyBoardIfNeeded = () => {
        const { autoFocusOnLoad, pinCount } = this.props;
        const digits = this.getDigits();
        const focusIndex = digits.length ? digits.length - 1 : 0;
        if (focusIndex < pinCount && autoFocusOnLoad) {
            this.focusField(focusIndex);
        }
    };
    getDigits = () => {
        const { digits: innerDigits } = this.state;
        const { code } = this.props;
        return code === undefined ? innerDigits : code.split('');
    };
    handleKeyboardDidHide = () => {
        this.blurAllFields();
    };
    notifyCodeChanged = () => {
        const { digits } = this.state;
        const code = digits.join('');
        const { onCodeChanged } = this.props;
        if (onCodeChanged) {
            onCodeChanged(code);
        }
    };
    checkPinCodeFromClipBoard = () => {
        const { pinCount, onCodeFilled } = this.props;
        const regexp = new RegExp(`^\\d{${pinCount}}$`);
        clipboard_1.default.getString()
            .then(code => {
            if (this.hasCheckedClipBoard &&
                regexp.test(code) &&
                this.clipBoardCode !== code) {
                this.setState({
                    digits: code.split(''),
                }, () => {
                    this.blurAllFields();
                    this.notifyCodeChanged();
                    onCodeFilled && onCodeFilled(code);
                });
            }
            this.clipBoardCode = code;
            this.hasCheckedClipBoard = true;
        })
            .catch(() => { });
    };
    handleChangeText = (index, text) => {
        const { onCodeFilled, pinCount } = this.props;
        const digits = this.getDigits();
        let newdigits = digits.slice();
        const oldTextLength = newdigits[index] ? newdigits[index].length : 0;
        const newTextLength = text.length;
        if (newTextLength - oldTextLength === pinCount) {
            // user pasted text in.
            newdigits = text.split('').slice(oldTextLength, newTextLength);
            this.setState({ digits: newdigits }, this.notifyCodeChanged);
        }
        else {
            if (text.length === 0) {
                if (newdigits.length > 0) {
                    newdigits = newdigits.slice(0, newdigits.length - 1);
                }
            }
            else {
                text.split('').forEach(value => {
                    if (index < pinCount) {
                        newdigits[index] = value;
                        index += 1;
                    }
                });
                index -= 1;
            }
            this.setState({ digits: newdigits }, this.notifyCodeChanged);
        }
        let result = newdigits.join('');
        if (result.length >= pinCount) {
            onCodeFilled && onCodeFilled(result);
            this.focusField(pinCount - 1);
            this.blurAllFields();
        }
        else {
            if (text.length > 0 && index < pinCount - 1) {
                this.focusField(index + 1);
            }
        }
    };
    handleKeyPressTextInput = (index, key) => {
        const digits = this.getDigits();
        if (key === 'Backspace') {
            if (!digits[index] && index > 0) {
                this.handleChangeText(index - 1, '');
                this.focusField(index - 1);
            }
        }
    };
    focusField = (index) => {
        if (index < this.fields.length) {
            this.fields[index].focus();
            this.setState({
                selectedIndex: index,
            });
        }
    };
    blurAllFields = () => {
        this.fields.forEach((field) => field.blur());
        this.setState({
            selectedIndex: -1,
        });
    };
    clearAllFields = () => {
        const { clearInputs, code } = this.props;
        if (clearInputs && code === '') {
            this.setState({ digits: [], selectedIndex: 0 });
        }
    };
    renderOneInputField = (_, index) => {
        const { secureTextEntry, editable, keyboardType, selectionColor, keyboardAppearance, } = this.props;
        const { selectedIndex, digits } = this.state;
        const { clearInputs, placeholderCharacter, placeholderTextColor, } = this.props;
        const removeOutline = { outlineStyle: 'none' };
        let inputStyle;
        if (this.props.type === 'curved') {
            inputStyle = inputOtpTextStyle_1.styles.common;
        }
        else {
            inputStyle = inputOtpTextStyle_1.styles.normalCommon;
        }
        return (react_1.default.createElement(react_native_1.View, { pointerEvents: "none", key: index + 'view', style: {
                flex: 1,
                marginRight: this.props.pinCount - 1 === index ? 0 : 16,
            } },
            react_1.default.createElement(ThemeContext_1.default.Consumer, null, Consumer => {
                const borderColor = selectedIndex === index
                    ? (0, themeHelper_1.primaryColor)(Consumer.theme)
                    : colors_1.BORDER_COLOR;
                return (react_1.default.createElement(react_native_1.TextInput, { style: [inputStyle, removeOutline, { borderColor }], ref: ref => {
                        this.fields[index] = ref;
                    }, onChangeText: text => {
                        this.handleChangeText(index, text);
                    }, onKeyPress: ({ nativeEvent: { key } }) => {
                        this.handleKeyPressTextInput(index, key);
                    }, value: !clearInputs ? digits[index] : '', keyboardAppearance: keyboardAppearance, keyboardType: keyboardType, textContentType: helpers_1.isAutoFillSupported ? 'oneTimeCode' : 'none', key: index, selectionColor: selectionColor, secureTextEntry: secureTextEntry, editable: editable, placeholder: placeholderCharacter, placeholderTextColor: placeholderTextColor }));
            })));
    };
    renderTextFields = () => {
        const { pinCount } = this.props;
        const array = new Array(pinCount).fill(0);
        return array.map(this.renderOneInputField);
    };
    render() {
        const { pinCount, style, clearInputs } = this.props;
        const digits = this.getDigits();
        return (react_1.default.createElement(react_native_1.View, { style: style },
            react_1.default.createElement(react_native_1.TouchableWithoutFeedback, { onPress: () => {
                    if (!clearInputs) {
                        let filledPinCount = digits.filter(digit => {
                            return digit !== null && digit !== undefined;
                        }).length;
                        this.focusField(Math.min(filledPinCount, pinCount - 1));
                    }
                    else {
                        this.clearAllFields();
                        this.focusField(0);
                    }
                } },
                react_1.default.createElement(react_native_1.View, { style: inputOtpTextStyle_1.styles.renderViewStyle }, this.renderTextFields()))));
    }
}
exports.default = InputOtpText;
