import React from 'react';
import { KeyboardTypeOptions, NativeSyntheticEvent, TextInput, TextInputKeyPressEventData, ViewStyle } from 'react-native';
import { textColors } from '../Text/Text';
export type InputAlign = 'left' | 'right' | 'center' | 'top';
export type InputTypes = 'normal' | 'curved' | 'rounded' | 'noBorder';
export type returnKeyType = 'default' | 'done' | 'none' | 'search' | 'go' | 'next' | 'send' | 'previous' | 'google' | 'join' | 'route' | 'yahoo' | 'emergency-call' | undefined;
export type textContentType = 'none' | 'URL' | 'addressCity' | 'addressCityAndState' | 'addressState' | 'countryName' | 'creditCardNumber' | 'emailAddress' | 'familyName' | 'fullStreetAddress' | 'givenName' | 'jobTitle' | 'location' | 'middleName' | 'name' | 'namePrefix' | 'nameSuffix' | 'nickname' | 'organizationName' | 'postalCode' | 'streetAddressLine1' | 'streetAddressLine2' | 'sublocality' | 'telephoneNumber' | 'username' | 'password' | 'newPassword' | 'oneTimeCode' | undefined;
export type autoCapitalize = 'none' | 'sentences' | 'words' | 'characters' | undefined;
export declare const isInputTextTypeKey: (str: string | undefined) => str is InputTypes;
type DefaultProps = {
    type: InputTypes;
    align: InputAlign;
    size: number;
    value: string;
    placeholderTextColor: string;
    minHeight: number;
    color: textColors;
    allowFontScaling: boolean;
    name: string;
    formikErrors: {
        [key: string]: string | undefined;
    };
    formikTouched: {
        [key: string]: boolean | undefined;
    };
    error: boolean | any;
};
declare const defaultProps: DefaultProps;
type Props = {
    required?: boolean;
    label?: string;
    autoFocus?: boolean;
    placeholder?: string;
    onChange?: (text: string) => void;
    onChangeNative?: (arg: any) => any;
    actionLeft?: Function;
    actionRight?: Function;
    flex?: number;
    overrideStyle?: ViewStyle;
    onBlur?: (arg: any) => any;
    onFocus?: (arg: any) => void;
    onClear?: boolean;
    disabled?: boolean;
    bold?: boolean;
    size?: number;
    multiline?: boolean;
    numberOfLines?: number;
    getRef?: (ref: React.RefObject<TextInput>) => void;
    onKeyPress?: ((e: NativeSyntheticEvent<TextInputKeyPressEventData>) => void) | undefined;
    onSubmitEditing?: () => void;
    returnKeyType?: returnKeyType;
    secureTextEntry?: boolean;
    maxLength?: number;
    keyboardType?: KeyboardTypeOptions;
    textContentType?: textContentType;
    autoCapitalize?: autoCapitalize;
    white?: boolean;
    labelSize?: number;
    labelColor?: textColors;
    underlineColorAndroid?: string;
} & typeof defaultProps;
declare const InputText: {
    ({ overrideStyle, onBlur, onFocus, required, label, type, autoFocus, value, placeholder, onChange, onChangeNative, actionLeft, actionRight, color, align, error, flex, disabled, bold, size, multiline, numberOfLines, onClear, onKeyPress, keyboardType, onSubmitEditing, returnKeyType, maxLength, secureTextEntry, placeholderTextColor, minHeight, getRef, textContentType, autoCapitalize, white, allowFontScaling, labelSize, labelColor, name, formikErrors, formikTouched, underlineColorAndroid }: Props): JSX.Element;
    defaultProps: DefaultProps;
};
export default InputText;
