"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isAutoFillSupported = exports.codeToArray = exports.getDateString = exports.errorHandler = exports.get = exports.useStateCallback = exports.dateFormatter = exports.openNewWindowHelper = exports.resolveObj = exports.removeUnderScores = exports.useComponentVisible = exports.isValidDate = exports.convertCurrencyFormat = exports.getTheme = void 0;
/* eslint-env browser */
const moment_1 = __importDefault(require("moment"));
const react_1 = require("react");
const react_native_1 = require("react-native");
const validators_1 = require("./validators");
const getTheme = () => 'app';
exports.getTheme = getTheme;
const convertCurrencyFormat = (value) => {
    if (typeof value === 'number' || typeof value === 'string') {
        return value.toString().replace(/(\d)(?=(\d\d)+\d$)/g, '$1,');
    }
    return '0';
};
exports.convertCurrencyFormat = convertCurrencyFormat;
const isValidDate = (date) => {
    const timestamp = Date.parse(date);
    return Number.isNaN(timestamp) === false;
};
exports.isValidDate = isValidDate;
const useComponentVisible = (initialIsVisible) => {
    const [isComponentVisible, setIsComponentVisible] = (0, react_1.useState)(initialIsVisible);
    const ref = (0, react_1.createRef)();
    const handleClickOutside = (event) => {
        if (ref.current && !ref.current.contains(event.target)) {
            setIsComponentVisible(false);
        }
    };
    (0, react_1.useEffect)(() => {
        if (typeof Window !== 'undefined') {
            document.addEventListener('click', handleClickOutside, true);
        }
        return () => {
            if (ref && typeof Window !== 'undefined') {
                document.removeEventListener('click', handleClickOutside, true);
            }
        };
    });
    return { ref, isComponentVisible, setIsComponentVisible };
};
exports.useComponentVisible = useComponentVisible;
const removeUnderScores = (status) => {
    if (typeof status === 'string') {
        return status.replace(/_/g, ' ');
    }
    return '';
};
exports.removeUnderScores = removeUnderScores;
const resolveObj = (obj, path) => {
    if (typeof path !== 'string' || (0, validators_1.isEmpty)(path)) {
        return '';
    }
    return path
        .split('.')
        .reduce((prev, curr) => (prev && prev[curr] ? prev[curr] : ''), obj);
};
exports.resolveObj = resolveObj;
const openNewWindowHelper = (url) => {
    if (typeof Window !== 'undefined') {
        const urlChecker = url[0] === 'h' ? url : window.location.origin + url;
        window.open(urlChecker);
    }
};
exports.openNewWindowHelper = openNewWindowHelper;
const dateFormatter = (timestamp) => {
    if ((0, exports.isValidDate)(timestamp)) {
        const formattedTimeStamp = new Date(timestamp).toLocaleString('default', {
            timeZone: 'Asia/Dhaka',
        });
        const monthNames = [
            'Jan',
            'Feb',
            'Mar',
            'Apr',
            'May',
            'Jun',
            'Jul',
            'Aug',
            'Sep',
            'Oct',
            'Nov',
            'Dec',
        ];
        const date = new Date(formattedTimeStamp).getDate();
        const month = new Date(formattedTimeStamp).getMonth();
        const year = new Date(formattedTimeStamp).getFullYear();
        return `${date} ${monthNames[month]} ${year}`;
    }
    return 'Invalid Date';
};
exports.dateFormatter = dateFormatter;
const useStateCallback = (initialState) => {
    const [state, setState] = (0, react_1.useState)(initialState);
    const callBackRef = (0, react_1.useRef)(null);
    const setStateCallback = (0, react_1.useCallback)((updatedState, callBack) => {
        callBackRef.current = callBack;
        setState(updatedState);
    }, []);
    (0, react_1.useEffect)(() => {
        if (callBackRef.current) {
            callBackRef.current(state);
            callBackRef.current = null;
        }
    }, [state]);
    return [state, setStateCallback];
};
exports.useStateCallback = useStateCallback;
const get = (obj, path) => path.split('.').reduce((p, c) => (p && p[c]) || null, obj);
exports.get = get;
const errorHandler = (response) => {
    throw new Error(response.error.message);
};
exports.errorHandler = errorHandler;
/**
 * Return the requested date format
 * @param value Date string or object
 * @param format returns the specified date format
 * @param isUnix converts to unix and returns unix formatted date
 * @param convertToLocal converts and returns to local timezone
 */
const getDateString = (value, format, isUnix, convertToLocal) => {
    if ((typeof value === 'string' ||
        typeof value === 'number' ||
        typeof value === 'object') &&
        !Array.isArray(value) &&
        !(0, validators_1.isEmpty)(format)) {
        if (isUnix) {
            return moment_1.default.unix(Number(value)).format(format);
        }
        else {
            if (convertToLocal)
                return moment_1.default.parseZone(value).local().format(format);
            return moment_1.default.parseZone(value).format(format);
        }
    }
    return '';
};
exports.getDateString = getDateString;
const codeToArray = (code) => code?.split('') ?? [];
exports.codeToArray = codeToArray;
const majorVersionIOS = parseInt(String(react_native_1.Platform.Version), 10);
exports.isAutoFillSupported = react_native_1.Platform.OS === 'ios' && majorVersionIOS >= 12;
